@@ -70,6 +70,7 @@ class TestAddonLoader(AddonsLoader):
         addon.enabled = True
         addon.name = 'lskdjflkjsdlfkjsdlkfjlsdfj'
         addon.target = "test"
+        addon.some_var = "cup cup"
         return addon
 
 
@@ -143,15 +144,16 @@ async def test(ctx: InputContext, container: AnyContainer):
             await container.ticket_service.give_metric(CounterMetric("SomeCounter"), kind="some_kind")
             return {'asdf': 234}
         case "GET":
+            loguru.logger.warning((await container.addon_loader().find_addon_by_target("test"))[0].__dict__)
             # loguru.logger.warning(ctx.request.app.router.routes)
-            loguru.logger.warning(dir(ctx.request.app.router.routes_all.get(('api', 'v1', 'test'))))
-            loguru.logger.warning(ctx.request.app.router.routes_all.get(('api', 'v1', 'test')).handler.__closure__)
-            loguru.logger.warning(
-                dir(ctx.request.app.router.routes_all.get(('api', 'v1', 'test')).handler.__closure__[0]))
-            loguru.logger.warning(ctx.request.app.router.routes_all.get(('api', 'v1', 'test')).handler.__closure__[
-                                      0].cell_contents.in_struct)
-            ctx.request.app.router.routes_all.get(('api', 'v1', 'test')).handler.__closure__[
-                0].cell_contents.in_struct = SomeDto
+            # loguru.logger.warning(dir(ctx.request.app.router.routes_all.get(('api', 'v1', 'test'))))
+            # loguru.logger.warning(ctx.request.app.router.routes_all.get(('api', 'v1', 'test')).handler.__closure__)
+            # loguru.logger.warning(
+            #     dir(ctx.request.app.router.routes_all.get(('api', 'v1', 'test')).handler.__closure__[0]))
+            # loguru.logger.warning(ctx.request.app.router.routes_all.get(('api', 'v1', 'test')).handler.__closure__[
+            #                           0].cell_contents.in_struct)
+            # ctx.request.app.router.routes_all.get(('api', 'v1', 'test')).handler.__closure__[
+            #     0].cell_contents.in_struct = SomeDto
             return await container.ticket_service.collect_metrics(JsonExporter(), kind="some_kind")
     return json({"ok": "ok"})
 
