@@ -163,13 +163,18 @@ class DictRouter(ExtRouter, Generic[GenericRequestHandler]):
                                              in_dto=method_conf.in_dto,
                                              out_dto=method_conf.out_dto)
 
-                if self.versioning:
-                    app.add_route(uri=route_conf.path,
-                                  methods={method_conf.method_name.upper()},
-                                  handler=chain,
-                                  version_prefix=method_conf.version_prefix,
-                                  version=method_conf.version)
+                if method_conf.method_name.lower() == 'websocket':
+                    app.add_websocket_route(
+                        handler=chain,
+                        uri=route_conf.path,
+                        version=method_conf.version if self.versioning else None,
+                        version_prefix=method_conf.version_prefix if self.versioning else None
+                    )
                 else:
-                    app.add_route(uri=route_conf.path,
-                                  methods={method_conf.method_name.upper()},
-                                  handler=chain)
+                    app.add_route(
+                        uri=route_conf.path,
+                        methods={method_conf.method_name.upper()},
+                        handler=chain,
+                        version=method_conf.version if self.versioning else None,
+                        version_prefix=method_conf.version_prefix if self.versioning else None
+                    )
